@@ -1,33 +1,22 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from trytond.model import ModelSQL, ModelView, fields, sequence_ordered
-
-__all__ = ['Routing', 'Operation', 'RoutingStep', 'Routing_BOM']
+from trytond.model import (
+    DeactivableMixin, ModelSQL, ModelView, fields, sequence_ordered)
 
 
-class Routing(ModelSQL, ModelView):
+class Routing(DeactivableMixin, ModelSQL, ModelView):
     'Routing'
     __name__ = 'production.routing'
     name = fields.Char('Name', required=True, translate=True)
-    active = fields.Boolean('Active', select=True)
     steps = fields.One2Many('production.routing.step', 'routing', 'Steps')
     boms = fields.Many2Many(
         'production.routing-production.bom', 'routing', 'bom', 'BOMs')
 
-    @classmethod
-    def default_active(cls):
-        return True
 
-
-class Operation(ModelSQL, ModelView):
+class RoutingOperation(DeactivableMixin, ModelSQL, ModelView):
     'Operation'
     __name__ = 'production.routing.operation'
     name = fields.Char('Operation', required=True, translate=True)
-    active = fields.Boolean('Active', select=True)
-
-    @classmethod
-    def default_active(cls):
-        return True
 
 
 class RoutingStep(sequence_ordered(), ModelSQL, ModelView):
@@ -38,6 +27,11 @@ class RoutingStep(sequence_ordered(), ModelSQL, ModelView):
     routing = fields.Many2One('production.routing', 'Routing', required=True,
         ondelete='CASCADE')
 
+    @classmethod
+    def __setup__(cls):
+        super().__setup__()
+        cls.__access__.add('routing')
+
     def get_rec_name(self, name):
         return self.operation.rec_name
 
@@ -49,6 +43,5 @@ class RoutingStep(sequence_ordered(), ModelSQL, ModelView):
 class Routing_BOM(ModelSQL):
     'Routing - BOM'
     __name__ = 'production.routing-production.bom'
-    routing = fields.Many2One('production.routing', 'Routing', required=True,
-        select=True)
-    bom = fields.Many2One('production.bom', 'BOM', required=True, select=True)
+    routing = fields.Many2One('production.routing', 'Routing', required=True)
+    bom = fields.Many2One('production.bom', 'BOM', required=True)
